# coding=UTF-8
"""
@Author: HuangJianYi
@Date: 2023-06-26 08:26:10
@LastEditTime: 2023-08-30 13:50:39
@LastEditors: HuangJianYi
@Description: 物流处理类（阿里云）
"""

import requests
from difflib import SequenceMatcher
from seven_cloudapp_frame.handlers.frame_base import *


class AliLogisticsHelper:
    """
    :description: 阿里物流处理类
    """
    logistics_url = 'https://wuliu.market.alicloudapi.com/kdi'  # 物流信息接口
    express_company_url = 'https://wuliu.market.alicloudapi.com/exCompany'  # 快递公司信息接口
    logger_error = Logger.get_logger_by_name("log_error")
    express_company_redis_key = "express_company_info"  # 快递公司redis_key

    @classmethod
    def get_logistics_info(self, express_no, express_company, recipient_phone):
        """
        :description: 获取物流信息
        :param express_no：快递单号
        :param express_company：快递公司
        :param recipient_phone：收件人手机号
        :return: InvokeResultData
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            wuliu_config = share_config.get_value("wuliu_config")
            if not wuliu_config or not wuliu_config["app_code"]:
                invoke_result_data.success = False
                invoke_result_data.error_message = "缺少配置信息"
                return invoke_result_data
            platform_redis = share_config.get_value("platform_redis") if share_config.get_value("platform_redis") else config.get_value("redis")
            redis_init = RedisHelper.redis_init(config_dict=platform_redis, decode_responses=True)
            # 获取redis缓存物流公司类型（缩写）
            express_company_type = redis_init.hget(self.express_company_redis_key, express_company)
            if not express_company_type:
                express_company_invoke_result_data = self.get_express_company(express_no, express_company)
                if express_company_invoke_result_data.success == False:
                    invoke_result_data.success = False
                    invoke_result_data.error_message = express_company_invoke_result_data.error_message
                    return invoke_result_data
                express_company_type = express_company_invoke_result_data.data['express_company_type']
            if '顺丰' in express_company:
                express_no += f":{str(recipient_phone[-4:])}"
            url = self.logistics_url + '?' + f'no={express_no}&type={express_company_type}'
            header = {"Authorization": 'APPCODE ' + wuliu_config["app_code"]}
            res = requests.get(url, headers=header)
            if res.status_code != 200:
                error_msg = self.get_error_info(res.status_code, res.headers['X-Ca-Error-Message'])
                invoke_result_data.success = False
                invoke_result_data.error_message = error_msg
                return invoke_result_data
            else:
                result_data = SevenHelper.json_loads(res.text)
                if result_data['status'] == '0':
                    invoke_result_data.data = result_data['result']
                else:
                    invoke_result_data.success = False
                    if result_data['status'] == '201':
                        invoke_result_data.error_message = "快递单号错误"
                    elif result_data['status'] == '203':
                        invoke_result_data.error_message = "快递公司不存在"
                    elif result_data['status'] == '204':
                        invoke_result_data.error_message = "快递公司识别失败"
                    elif result_data['status'] == '205':
                        invoke_result_data.error_message = "快递单号无法查询到信息"
                    elif result_data['status'] == '207':
                        invoke_result_data.error_message = "该单号被限制，错误单号"

        except Exception as ex:
            self.logger_error.error("【获取物流信息异常】" + traceback.format_exc())
            invoke_result_data.success = False
            invoke_result_data.error_message = "获取物流信息异常，请联系客服"
        return invoke_result_data

    @classmethod
    def get_express_company(self, express_no, express_company):
        """
        :description: 获取快递公司（根据快递单号）
        :param express_no：快递单号
        :param express_company：快递公司
        :return: list
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        try:
            wuliu_config = share_config.get_value("wuliu_config")
            if not wuliu_config or not wuliu_config["app_code"]:
                invoke_result_data.success = False
                invoke_result_data.error_message = "缺少配置信息"
                return invoke_result_data
            url = self.express_company_url + '?' + f'no={express_no}'
            header = {"Authorization": 'APPCODE ' + wuliu_config["app_code"]}
            res = requests.get(url, headers=header)
            if res.status_code != 200:
                error_msg = self.get_error_info(res.status_code, res.headers['X-Ca-Error-Message'])
                invoke_result_data.success = False
                invoke_result_data.error_message = error_msg
                return invoke_result_data
            else:
                result_data = SevenHelper.json_loads(res.text)
                if result_data['status'] == '0' and result_data['list']:
                    invoke_result_data.data = {"express_company_type": ""}  # 快递公司类型（缩写）
                    similarity_ratio = 0  # 匹配度
                    for express_company_dict in result_data['list']:
                        curr_similarity_ratio = SequenceMatcher(None, express_company, express_company_dict['name']).ratio()
                        if similarity_ratio < curr_similarity_ratio:
                            similarity_ratio = curr_similarity_ratio
                            invoke_result_data.data['express_company_type'] = express_company_dict['type']
                    if not invoke_result_data.data['express_company_type']:
                        invoke_result_data.success = False
                        invoke_result_data.error_message = "无法匹配快递公司信息"
                        return invoke_result_data
                    # 匹配度超过90%，保存到redis
                    if similarity_ratio > 0.9:
                        platform_redis = share_config.get_value("platform_redis") if share_config.get_value("platform_redis") else config.get_value("redis")
                        redis_init = RedisHelper.redis_init(config_dict=platform_redis)
                        redis_init.hset(self.express_company_redis_key, express_company, str(invoke_result_data.data['express_company_type']))
                else:
                    invoke_result_data.success = False
                    invoke_result_data.error_message = "未找到快递公司信息"
                    return invoke_result_data
        except Exception as ex:
            self.logger_error.error("【获取快递公司（根据快递单号）】" + traceback.format_exc())
            invoke_result_data.success = False
            invoke_result_data.error_message = "获取快递公司信息异常，请联系客服"
        return invoke_result_data

    @classmethod
    def get_error_info(self, http_status_code, http_reason):
        """
        :description: 获取快递公司（根据快递单号）
        :param http_status_code：http状态码
        :param http_reason：原因
        :return: str
        :last_editors: HuangJianYi
        """
        error_msg = ""
        if (http_status_code == 400 and http_reason == 'Invalid Param Location'):
            error_msg = "参数错误"
        elif (http_status_code == 400 and http_reason == 'Invalid AppCode'):
            error_msg = "AppCode错误"
        elif (http_status_code == 400 and http_reason == 'Invalid Url'):
            error_msg = "请求的 Method、Path 或者环境错误"
        elif (http_status_code == 403 and http_reason == 'Unauthorized'):
            error_msg = "服务未被授权（或URL和Path不正确）"
        elif (http_status_code == 403 and http_reason == 'Quota Exhausted'):
            error_msg = "套餐包次数用完"
        elif (http_status_code == 403 and http_reason == 'Api Market Subscription quota exhausted'):
            error_msg = "套餐包次数用完，请续购套餐"
        elif (http_status_code == 500):
            error_msg = "API网关错误"
        else:
            error_msg = "参数名错误 或 其他错误"
        return error_msg


# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-06-02 14:32:40
@LastEditTime: 2024-01-30 19:49:32
@LastEditors: HuangJianYi
:description: 枚举类
"""

from enum import Enum
from enum import unique


@unique
class PlatType(Enum):
    """
    :description: 平台类型
    """
    tb = 1 #淘宝
    wx = 2 #微信
    dy = 3 #抖音
    web = 4 #站点
    jd = 5 #京东

@unique
class PageCountMode(Enum):
    """
    :description: 分页模式
    """
    none = 0 #无
    total = 1 #总数
    next = 2 #是否有下一页

@unique
class OperationType(Enum):
    """
    :description: 用户操作日志类型
    """
    add = 1 #新增
    update = 2 #编辑
    delete = 3 #删除
    review = 4 #还原
    copy = 5 #复制
    export = 6 #导出
    import_data = 7 #导入
    release = 8 #上架
    un_release = 9 #下架
    operate = 10 #操作


@unique
class FileStorageType(Enum):
    """
    :description: 文件存储类型
    """
    oss = 1  #阿里云
    cos = 2  #腾讯云
    bos = 3  #百度云


@unique
class SmsType(Enum):
    """
    :description: 短信渠道类型
    """
    ali = 1  #阿里云
    tencent = 2  #腾讯云
    bce = 3  #百度云

@unique
class UserType(Enum):
    """
    :description: 用户类型
    """
    product = 0  #产品用户
    app = 1  #应用用户
    act = 2  #活动用户


@unique
class TaskRewardType(Enum):
    """
    :description: 任务奖励类型
    """
    asset = 1 #资产
    prize = 2 #奖品
    card = 3 #卡片

@unique
class TaskCompleteType(Enum):
    """
    :description: 任务完成类型
    """
    day = 1 #每日任务
    week = 2 #每周任务
    month = 4 #每月任务
    long = 3 #持久任务

@unique
class TaskType(Enum):
    """
    docstring：任务类型 业务的自定义任务类型从201起
    """
    # 掌柜有礼、免费领取、新人有礼，格式：{"reward_value":0,"asset_object_id":""}  字段说明：reward_value:奖励值 asset_object_id:资产对象标识
    free_gift = 1
    # 单次签到，格式：{"reward_value":0,"asset_object_id":""}  字段说明：reward_value:奖励值 asset_object_id:资产对象标识
    one_sign = 2
    # 每周签到(指定天数签到)，格式：{"day_list":[{'day': 1, 'reward_value': 1}, {'day': 2, 'reward_value': 1}, {'day': 3, 'reward_value': 1}, {'day': 4, 'reward_value': 1}, {'day': 5, 'reward_value': 1}, {'day': 6, 'reward_value': 1}, {'day': 7, 'reward_value': 1}],"asset_object_id":""}  字段说明：day_array:每天奖励配置列表 asset_object_id:资产对象标识
    weekly_sign = 3
    # 邀请新用户，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    invite_new_user = 4
    # 邀请入会，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""}  字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    invite_join_member = 5
    # 关注店铺，格式：{"reward_value":0,"once_favor_reward":0,"asset_object_id":""} 字段说明：reward_value:奖励值 once_favor_reward:已关注是否奖励1是0否 asset_object_id:资产对象标识
    favor_store = 6
    # 加入店铺会员，格式：{"reward_value":0,"once_member_reward":0,"asset_object_id":""} 字段说明：reward_value:奖励值 once_member_reward:已入会是否奖励1是0否 asset_object_id:资产对象标识
    join_member = 7
    # 收藏商品，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:商品ID串 goods_list:商品列表
    collect_goods = 8
    # 浏览商品，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:商品ID串 goods_list:商品列表
    browse_goods = 9
    # 浏览店铺(进店逛逛)，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 或者 [{"id":1,"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""}] 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    browse_store = 10
    # 浏览直播间(观看直播间)，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"link_url":"","asset_object_id":""} 或者 [{"id":1,"reward_value":0,"satisfy_num":1,"limit_num":0,"link_url":"","asset_object_id":""}] 字段说明：reward_value:奖励值 link_url:链接地址 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    browse_live_room = 11
    # 浏览会场/专题，格式：[{"id":"","reward_value":0,"link_url":"","satisfy_num":1,"limit_num":1,"asset_object_id":""}] 字段说明：id:子任务类型,必填 reward_value:奖励值 satisfy_num:满足数  link_url:链接地址 asset_object_id:资产对象标识 limit_num:完成限制数
    browse_special_topic = 12
    # 累计签到，格式：{"day_list":[{'day': 1, 'reward_value': 1}, {'day': 2, 'reward_value': 1}],"asset_object_id":""} 字段说明： day_list:每天奖励配置列表 asset_object_id:资产对象标识
    cumulative_sign = 13
    # 分享，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    share = 14
    # 邀请用户助力(不判断是否新用户，可重复邀请)，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 limit_num:完成限制数 asset_object_id:资产对象标识
    invite_user_help = 15
    # 神秘暗号，格式：{"reward_value":0,"secret_code":"","asset_object_id":""} 字段说明：reward_value:奖励值 secret_code:暗号 asset_object_id:资产对象标识
    secret_code = 16
    # 店铺会员积分兑换资产，格式：{"reward_value":1,"satisfy_num":1,"limit_num":1} 字段说明：reward_value:奖励值 satisfy_num:需要的积分 limit_num:完成限制数
    crm_point_exchange_asset = 17
    # 连续签到（天数是连续递增），格式：{"day_list":[{'day': 1, 'reward_value': 1}, {'day': 2, 'reward_value': 1}],"asset_object_id":""} 字段说明： day_list:每天奖励配置列表 asset_object_id:资产对象标识
    successive_sign = 18
    # 购买指定商品，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:商品ID串 goods_list:商品列表
    buy_appoint_goods = 19
    # 购买指定商品每多少金额，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:商品ID串 goods_list:商品列表
    buy_appoint_goods_price = 20
    # 购买指定商品档位金额任务，格式：{"gear_list":[{"id":1,"gear":0,"reward_type":1,"reward_name":"","asset_object_id":"","reward_value":1}],"goods_ids":"","goods_list":[]} 字段说明：id:前端生成的唯一标识 gear:档位阀值 reward_value:奖励值(等于0无法领取) reward_type:奖励类型 reward_name:奖励奖品名称 asset_object_id:对象标识(如果奖励类型是资产对应资产对象标识，如果是奖品对应奖品标识，如果是卡片对应卡片标识) goods_ids:商品ID串 goods_list:商品列表
    buy_appoint_goods_price_gear = 21
    # 购买全店商品每多少金额，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"goods_ids":"","goods_list":[],"asset_object_id":""} 字段说明：reward_value:奖励值 satisfy_num:满足数 asset_object_id:资产对象标识 limit_num:完成限制数 goods_ids:排除的商品ID串 goods_list:排除的商品列表
    buy_store_price = 22
    # 购买全店商品档位金额任务，格式：{"gear_list":[{"id":1,"gear":0,"reward_type":1,"reward_name":"","asset_object_id":"","reward_value":1}]} 字段说明：id:前端生成的唯一标识 gear:档位阀值 reward_value:奖励值(等于0无法领取) reward_type:奖励类型 reward_name:奖励奖品名称 asset_object_id:对象标识(如果奖励类型是资产对应资产对象标识，如果是奖品对应奖品标识，如果是卡片对应卡片标识)  goods_ids:排除的商品ID串 goods_list:排除的商品列表
    buy_store_price_gear = 23
    # 每多少次抽盒/抽包/抽奖，格式：{"reward_value":0,"satisfy_num":1,"limit_num":0,"asset_object_id":""}  字段说明：reward_value:奖励值 satisfy_num:满足数（当大于1时才需要配置字段） limit_num:完成限制数 asset_object_id:资产对象标识
    lottery = 24
    #试抽，格式：{"reward_value":0,"limit_num":0,"asset_object_id":""}  字段说明：reward_value:奖励值 satisfy_num:满足数（当大于1时才需要配置字段） limit_num:完成限制数 asset_object_id:资产对象标识
    lottery_try = 25
    # 抽盒/抽包-档位任务，格式：{"gear_list":[{"id":1,"gear":0,"reward_type":1,"reward_name":"","asset_object_id":"","reward_value":1}]} 字段说明：id:前端生成的唯一标识 gear:档位阀值 reward_value:奖励值(等于0无法领取) reward_type:奖励类型 reward_name:奖励奖品名称 asset_object_id:对象标识(如果奖励类型是资产对应资产对象标识，如果是奖品对应奖品标识，如果是卡片对应卡片标识)
    lottery_gear = 26



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2022-04-24 15:15:19
@LastEditTime: 2024-02-01 18:48:16
@LastEditors: HuangJianYi
@Description: 
"""

from seven_framework.web_tornado.base_handler.base_api_handler import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.libs.customize.cryptography_helper import *
from seven_cloudapp_frame.libs.customize.safe_helper import *
from seven_cloudapp_frame.models.app_base_model import *
from urllib.parse import parse_qs


def filter_check_params(must_params=None, check_user_code=False):
    """
    :description: 参数过滤装饰器 仅限handler使用,
                  提供参数的检查及获取参数功能
                  装饰器使用方法:
                  @client_filter_check_params("param_a,param_b,param_c")  或
                  @client_filter_check_params(["param_a","param_b,param_c"])
                  参数获取方法:
                  self.request_params[param_key]
    :param must_params: 必须传递的参数集合
    :param check_user_code: 是否校验用户标识必传
    :last_editors: HuangJianYi
    """
    def check_params(handler):
        def wrapper(self, **args):
            finally_must_params = must_params
            if hasattr(self, "must_params"):
                finally_must_params = self.must_params
            if type(finally_must_params) == str:
                must_array = finally_must_params.split(",")
            if type(finally_must_params) == list:
                must_array = finally_must_params

            if finally_must_params:
                for must_param in must_array:
                    if not must_param in self.request_params or self.request_params[must_param] == "":
                        self.response_json_error("param_error", f"参数错误,缺少必传参数{must_param}")
                        return
            if check_user_code == True and not self.get_user_id():
                self.response_json_error("param_error", f"参数错误,缺少必传参数user_code")
                return

            return handler(self, **args)

        return wrapper

    return check_params


def filter_check_current_limit(handler_name=None, current_limit_count=0):
    """
    :description: 流量限制过滤装饰器 仅限handler使用
    :param handler_name: handler名字
    :param current_limit_count: 流量限制数量
    :last_editors: HuangJianYi
    """
    def check_current(handler):
        def wrapper(self, **args):
            app_base_model = AppBaseModel(context=self)
            app_id = self.get_app_id()
            open_id = self.get_open_id()
            limit_count = current_limit_count
            if limit_count == 0:
                app_info_dict = app_base_model.get_app_info_dict(app_id,True,"current_limit_count")
                limit_count = app_info_dict["current_limit_count"] if app_info_dict else 0
            if SafeHelper.check_current_limit(app_id, limit_count, handler_name) == True:
                self.response_json_error("current_limit", "当前人数过多,请稍后再试")
                return
            if handler_name:
                SafeHelper.add_current_limit_count(app_id, open_id, handler_name)

            return handler(self, **args)

        return wrapper

    return check_current





# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-08-03 15:42:53
@LastEditTime: 2024-02-02 09:08:34
@LastEditors: HuangJianYi
@Description: 活动模块
"""
from seven_cloudapp_frame.models.enum import *
from seven_cloudapp_frame.handlers.frame_base import *
from seven_cloudapp_frame.models.act_base_model import *
from seven_cloudapp_frame.models.seven_model import PageInfo


class ActTypeListHandler(ClientBaseHandler):
    """
    :description: 获取活动类型列表
    """
    def get_async(self):
        """
        :description: 获取活动类型列表
        :param marketing_id：营销方案标识
        :param is_act：当前类型是否创建过活动
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        is_act = int(self.get_param("is_act", 0))
        marketing_id = int(self.get_param("marketing_id", 0))
        condition_where = ConditionWhere()
        if marketing_id > 0:
            condition_where.add_condition("market_ids LIKE '%," + str(marketing_id) + ",%'")
        condition_where.add_condition("is_release=1")
        act_type_list = ActTypeModel(context=self).get_cache_list(where=condition_where.to_string())
        new_list = []
        for act_type in act_type_list:
            act_type.play_process_json = self.json_loads(act_type.play_process_json) if act_type.play_process_json else {}
            act_type.suit_behavior_json = self.json_loads(act_type.suit_behavior_json) if act_type.suit_behavior_json else {}
            act_type.market_function_json = self.json_loads(act_type.market_function_json) if act_type.market_function_json else {}
            act_type.type_desc = self.json_loads(act_type.type_desc) if act_type.type_desc else []
            act_type.task_asset_type_json = self.json_loads(act_type.task_asset_type_json) if act_type.task_asset_type_json else []
            if is_act > 0 and app_id:
                act_dict = ActInfoModel(context=self).get_cache_dict("app_id=%s and act_type=%s", limit="1", field="id", params=[app_id, act_type.id])
                if act_dict:
                    act_type.act_id = act_dict['id']
                else:
                    act_type.act_id = 0
            new_list.append(act_type.__dict__)
        return self.response_json_success(new_list)


class AddActInfoHandler(ClientBaseHandler):
    """
    :description: 添加活动信息
    """
    @filter_check_params("act_type")
    def get_async(self):
        """
        :description: 添加活动信息
        :param app_id：应用标识
        :param act_id：活动标识
        :param act_name：活动名称
        :param is_release：是否发布
        :param theme_id: 主题标识
        :param is_share: 是否开启分享
        :param share_desc_json: 分享配置
        :param is_rule: 是否开启规则
        :param rule_desc_json: 规则配置
        :param start_date: 开始时间
        :param end_date: 结束时间
        :param close_word: 关闭文案
        :param is_black：是否开启退款惩罚
        :param refund_count：退款成功次数
        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
        :param is_fictitious: 是否开启虚拟中奖（1是0否）
        :param i1: i1
        :param i2: i2
        :param i3: i3
        :param i4: i4
        :param i5: i5
        :param s1: s1
        :param s2: s2
        :param s3: s3
        :param s4: s4
        :param s5: s5
        :param d1: d1
        :param d2: d2
        :param agreement_json: 协议配置（用户协议或隐私条款）
        :param brand_json: 品牌配置
        :param business_type: 业务类型
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_name = self.get_param("act_name")
        act_type = int(self.get_param("act_type", 0))
        theme_id = int(self.get_param("theme_id", 0))
        close_word = self.get_param("close_word","抱歉，程序维护中")
        share_desc_json = self.get_param("share_desc_json", None)
        rule_desc_json = self.get_param("rule_desc_json", None)
        is_share = self.get_param_int("is_share", 0)
        is_rule = self.get_param_int("is_rule", 0)
        is_release = self.get_param_int("is_release", 0)
        start_date = self.get_param("start_date", None)
        end_date = self.get_param("end_date", None)
        is_black = int(self.get_param("is_black", -1))
        refund_count = int(self.get_param("refund_count", -1))
        join_ways = int(self.get_param("join_ways", -1))
        is_fictitious = int(self.get_param("is_fictitious", -1))
        store_url = self.get_param("store_url", None)
        i1 = int(self.get_param("i1", -1))
        i2 = int(self.get_param("i2", -1))
        i3 = int(self.get_param("i3", -1))
        i4 = int(self.get_param("i4", -1))
        i5 = int(self.get_param("i5", -1))
        s1 = self.get_param("s1", None)
        s2 = self.get_param("s2", None)
        s3 = self.get_param("s3", None)
        s4 = self.get_param("s4", None)
        s5 = self.get_param("s5", None)
        d1 = self.get_param("d1", None)
        d2 = self.get_param("d2", None)
        is_visit_store = int(self.get_param("is_visit_store", -1))
        agreement_json = self.get_param("agreement_json", None)
        brand_json = self.get_param("brand_json", None)
        business_type = self.get_param_int("business_type", -1)


        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word, is_share, is_rule, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json, business_type=business_type)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title= title_prefix + ";" + act_name)
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success(invoke_result_data.data.id)


class UpdateActInfoHandler(ClientBaseHandler):
    """
    :description: 修改活动信息
    """
    def post_async(self):
        """
        :description: 修改活动信息
        :param app_id：应用标识
        :param act_id：活动标识
        :param act_name：活动名称
        :param is_release：是否发布
        :param theme_id: 主题标识
        :param is_share: 是否开启分享
        :param share_desc_json: 分享配置
        :param is_rule: 是否开启规则
        :param rule_desc_json: 规则配置
        :param start_date: 开始时间
        :param end_date: 结束时间
        :param close_word: 关闭文案
        :param is_black：是否开启退款惩罚
        :param refund_count：退款成功次数
        :param join_ways: 活动参与条件（0所有1关注店铺2加入会员3指定用户）
        :param is_fictitious: 是否开启虚拟中奖（1是0否）
        :param i1: i1
        :param i2: i2
        :param i3: i3
        :param i4: i4
        :param i5: i5
        :param s1: s1
        :param s2: s2
        :param s3: s3
        :param s4: s4
        :param s5: s5
        :param d1: d1
        :param d2: d2
        :param agreement_json: 协议配置（用户协议或隐私条款）
        :param brand_json: 品牌配置
        :param business_type: 业务类型
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        act_name = self.get_param("act_name", None)
        theme_id = int(self.get_param("theme_id", -1))
        is_share = int(self.get_param("is_share", -1))
        share_desc_json = self.get_param("share_desc_json", None)
        is_rule = int(self.get_param("is_rule", -1))
        rule_desc_json = self.get_param("rule_desc_json", None)
        is_release = int(self.get_param("is_release", -1))
        start_date = self.get_param("start_date", None)
        end_date = self.get_param("end_date", None)
        is_black = int(self.get_param("is_black", -1))
        refund_count = int(self.get_param("refund_count", -1))
        join_ways = int(self.get_param("join_ways", -1))
        is_fictitious = int(self.get_param("is_fictitious", -1))
        close_word = self.get_param("close_word", None)
        is_visit_store = int(self.get_param("is_visit_store", -1))
        store_url = self.get_param("store_url", None)
        i1 = int(self.get_param("i1", -1))
        i2 = int(self.get_param("i2", -1))
        i3 = int(self.get_param("i3", -1))
        i4 = int(self.get_param("i4", -1))
        i5 = int(self.get_param("i5", -1))
        s1 = self.get_param("s1", None)
        s2 = self.get_param("s2", None)
        s3 = self.get_param("s3", None)
        s4 = self.get_param("s4", None)
        s5 = self.get_param("s5", None)
        d1 = self.get_param("d1", None)
        d2 = self.get_param("d2", None)
        agreement_json = self.get_param("agreement_json", None)
        brand_json = self.get_param("brand_json", None)
        business_type = self.get_param_int("business_type", -1)

        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store, agreement_json, brand_json, business_type=business_type)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        act_name = act_name if act_name else ''
        self.create_operation_log(operation_type=OperationType.update.value, model_name="act_info_tb", old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=title_prefix + ";" + act_name)
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ActInfoListHandler(ClientBaseHandler):
    """
    :description: 活动列表
    """
    def get_async(self):
        """
        :description: 获取活动列表
        :param app_id：应用标识
        :param act_name: 活动名称
        :param act_type: 活动类型
        :param business_type: 业务类型
        :param is_del: 是否回收站1是0否
        :param is_release: 是否发布1是0否
        :param page_size: 条数
        :param page_index: 页数
        :return: PageInfo
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        page_index = self.get_param_int("page_index", 0)
        page_size = self.get_param_int("page_size", 20)
        is_del = self.get_param_int("is_del", 0)
        is_release = self.get_param_int("is_release", -1)
        act_type = self.get_param_int("act_type", -1)
        business_type = self.get_param_int("business_type", -1)
        act_name = self.get_param("act_name")

        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_success({"data": []})
        if not app_id:
            return self.response_json_success({"data": []})
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id asc"
        app_base_model = AppBaseModel(context=self)
        act_base_model = ActBaseModel(context=self)
        page_list, total = act_base_model.get_act_info_list(app_id, act_name, is_del, page_size, page_index, False, act_type, is_release, order_by, business_type=business_type)
        for page in page_list:
            page["online_url"] = app_base_model.get_online_url(act_id=page['id'], app_id=app_id, act_type=page['act_type'])
            page["live_url"] = app_base_model.get_live_url(app_id)
        ref_params = {}
        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params))
        return self.response_json_success(page_info)


class ActInfoHandler(ClientBaseHandler):
    """
    :description: 获取活动信息
    """
    def get_async(self):
        """
        :description: 获取活动信息
        :param app_id：应用标识
        :param act_id：活动标识
        :return:
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        act_base_model = ActBaseModel(context=self)
        app_base_model = AppBaseModel(context=self)
        act_info_dict = act_base_model.get_act_info_dict(act_id, False, False)
        if act_info_dict:
            if SafeHelper.check_app_id(act_info_dict["app_id"], app_id) == False:
                act_info_dict = {}
                return self.response_json_success(act_info_dict)
            act_info_dict["finish_menu_config_json"] = self.json_loads(act_info_dict["finish_menu_config_json"]) if act_info_dict["finish_menu_config_json"] else []
            act_info_dict["share_desc_json"] = self.json_loads(act_info_dict["share_desc_json"]) if act_info_dict["share_desc_json"] else {}
            act_info_dict["rule_desc_json"] = self.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
            act_info_dict["agreement_json"] = self.json_loads(act_info_dict["agreement_json"]) if act_info_dict["agreement_json"] else []
            act_info_dict["brand_json"] = self.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}
            act_info_dict['online_url'] = app_base_model.get_online_url(act_id=act_info_dict['id'], app_id=act_info_dict['app_id'], act_type=act_info_dict["act_type"])
            act_info_dict['live_url'] = app_base_model.get_live_url(act_info_dict['app_id'])
        ref_params = {}
        return self.response_json_success(self.business_process_executed(act_info_dict, ref_params))


class DeleteActInfoHandler(ClientBaseHandler):
    """
    :description: 删除活动
    """
    def get_async(self):
        """
        :description: 删除活动
        :param app_id：应用标识
        :param act_id：活动标识
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 1)
        if invoke_result_data.success ==False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ReviewActInfoHandler(ClientBaseHandler):
    """
    :description: 还原活动
    """
    def get_async(self):
        """
        :description: 还原活动
        :param app_id：应用标识
        :param act_id：活动标识
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 0)
        if invoke_result_data.success ==False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class ReleaseActInfoHandler(ClientBaseHandler):
    """
    :description: 上下架活动
    """
    def get_async(self):
        """
        :description: 上下架活动
        :param app_id：应用标识
        :param act_id：活动标识
        :param is_release: 是否发布 1-是 0-否
        :return:
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        is_release = int(self.get_param("is_release", 0))
        invoke_result_data = self.business_process_executing()
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        if not invoke_result_data.data:
            invoke_result_data.data = {}
        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动"
        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.release_act_info(app_id, act_id, is_release)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
        self.create_operation_log(operation_type=operation_type, model_name="act_info_tb", title= title_prefix + ";" + invoke_result_data.data["act_name"])
        ref_params = {}
        invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()


class CreateActQrCodeHandler(ClientBaseHandler):
    """
    :description: 创建活动二维码
    """
    @filter_check_params("url")
    def get_async(self):
        """
        :description: 创建活动二维码
        :return: 活动二维码图片
        :last_editors: HuangJianYi
        """
        url = self.get_param("url")
        img, img_bytes = QRCodeHelper.create_qr_code(url, fill_color="black")
        img_base64 = base64.b64encode(img_bytes).decode()
        return self.response_json_success(f"data:image/jpeg;base64,{img_base64}")


class NextProgressHandler(ClientBaseHandler):
    """
    :description: 下一步配置
    """
    @filter_check_params("finish_key")
    def get_async(self):
        """
        :description: 下一步配置
        :param app_id：应用标识
        :param act_id：活动标识
        :param finish_key：完成key，由前端控制是否完成配置，完成时需传参数值finish_config 代表最后一步
        :return 
        :last_editors: HuangJianYi
        """
        app_id = self.get_app_id()
        act_id = self.get_act_id()
        finish_key = self.get_param("finish_key")

        act_base_model = ActBaseModel(context=self)
        invoke_result_data = act_base_model.next_progress(app_id, act_id, finish_key)
        if invoke_result_data.success == False:
            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
        return self.response_json_success()